<?php
/**
 * Server side action for Stripe Payment Element.
 * @version 1.0.0
 * @author OLD-ONE
 * @copyright OLD-ONE
 * @see https://stripe.com/docs/libraries?locale=ja-JP    Install Stripe PHP library    $ composer require stripe/stripe-php
 */

// Stripe PHP SDK
require_once 'vendor/autoload.php';
// Load Stripe secret key
require_once 'secrets.php';

header('Content-Type: application/json');
try {
    // Retrieve JSON from POST body
    $json_str = file_get_contents('php://input');
    $json_obj = json_decode($json_str);
    $description = $json_obj->description ?? 'Stripe order';
    $amount = $json_obj->amount ?? 0;
    $currency = $json_obj->currency ?? 'jpy';
    $email = $json_obj->email ?? '';
    $capture_method = $json_obj->capture_method ?? 'automatic';
    $setup_future_usage = $json_obj->setup_future_usage ?? null;
    $payment_intent_args = [
        'description' => $description,
        'amount' => (int) $amount,
        'currency' => strtolower($currency),
        'capture_method' => $capture_method, // [ automatic | automatic_async | manual ]
        'setup_future_usage' => $setup_future_usage,
        'automatic_payment_methods' => [
            'enabled' => true,
        ],
    ];
    if ($email) {
        $payment_intent_args['receipt_email'] = $email;
    }
    // Set Stripe secret key
    \Stripe\Stripe::setApiKey($stripe_secret_key);
    // Create a PaymentIntent with amount and currency
    $payment_intent = \Stripe\PaymentIntent::create($payment_intent_args);
    $output = [
        'client_secret' => $payment_intent->client_secret,
        'payment_intent_id' => $payment_intent->id,
    ];
    echo json_encode($output);
} catch (Error $e) {
    http_response_code(500);
    echo json_encode(['error' => $e->getMessage()]);
}
